@@ -100,6 +100,27 @@ ggv_control_finalize (GObject *object)
 	G_OBJECT_CLASS (ggv_control_parent_class)->finalize (object);
 }
 
+static gboolean
+is_auto_fit_set(GgvControl *control)
+{
+	GgvPostScriptView *ps_view;
+	GtkWidget *gs;
+
+	ps_view = control->priv->ps_view;
+	gs = ggv_postscript_view_get_widget(ps_view);
+
+	switch(gtk_gs_get_zoom_mode(GTK_GS(gs))) {
+	case GTK_GS_ZOOM_ABSOLUTE:
+		return FALSE;
+	case GTK_GS_ZOOM_FIT_WIDTH:
+	case GTK_GS_ZOOM_FIT_PAGE:
+		return TRUE;
+	default:
+		return FALSE;
+	}
+
+}
+
 static void
 sync_zoom_level_items(GgvControl *control)
 {
@@ -289,6 +310,60 @@ scrollbar_button_release_event(GtkWidget *widget, GdkEventButton *event,
 	return FALSE;
 }
 
+static void
+sw_size_allocate(GtkWidget *widget, GtkAllocation *alloc, gpointer data)
+{
+	GtkGS *view = GTK_GS(data);
+	guint border = gtk_container_get_border_width(GTK_CONTAINER(widget));
+	gint w, h;
+
+	w = alloc->width - 2*border;
+	h = alloc->height - 2*border;
+	w = MAX(w, 0);
+	h = MAX(h, 0);
+	gtk_gs_set_available_size(view, w, h);
+}
+
+static void
+_set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolean sens)
+{
+	gchar *prop_val = sens?"1":"0";
+	Bonobo_UIContainer container;
+	gint i;
+
+	container = bonobo_ui_component_get_container (uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
+
+	bonobo_ui_component_freeze(uic, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/ZoomIn",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/ZoomOut",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/ZoomToDefault",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/ZoomToFit",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/ZoomToFitWidth",
+								 "sensitive", prop_val, NULL);
+	for(i = 0; zoom_level_items[i].path != NULL; i++) {
+		bonobo_ui_component_set_prop(uic, zoom_level_items[i].path,
+									 "sensitive", prop_val, NULL);
+	}
+	bonobo_ui_component_thaw(uic, NULL);
+}
+
+static void
+set_zoom_items_sensitivity(GgvControl *control, gboolean sens)
+{
+	bonobo_ui_component_set_prop(control->priv->uic,
+								 "/Sidebar/Zoom Control Placeholder/ZoomControl",
+								 "sensitive", sens?"1":"0", NULL);
+	_set_zoom_items_sensitivity(control, control->priv->uic, sens);
+	if(control->priv->popup_uic != NULL)
+		_set_zoom_items_sensitivity(control, control->priv->popup_uic, sens);
+}
+
 static void
 listener_ZoomLevel_cb(BonoboUIComponent *uic, const char *path,
 					  Bonobo_UIComponent_EventType type, const char *state,
@@ -343,13 +418,18 @@ listener_AutoFitMode_cb(BonoboUIComponent *uic, const char *path,
 	control = GGV_CONTROL(user_data);
 	gs = GTK_GS(ggv_postscript_view_get_widget(control->priv->ps_view));
 
-	if(!strcmp(path, "AutoFitNone"))
+	if(!strcmp(path, "AutoFitNone")) {
 		gtk_gs_set_zoom_mode(gs, GTK_GS_ZOOM_ABSOLUTE);
-	if(!strcmp(path, "AutoFitWidth"))
+		set_zoom_items_sensitivity(control, TRUE);
+	}
+	if(!strcmp(path, "AutoFitWidth")) {
 		gtk_gs_set_zoom_mode(gs, GTK_GS_ZOOM_FIT_WIDTH);
-	if(!strcmp(path, "AutoFitPage"))
+		set_zoom_items_sensitivity(control, FALSE);
+	}
+	if(!strcmp(path, "AutoFitPage")) {
 		gtk_gs_set_zoom_mode(gs, GTK_GS_ZOOM_FIT_PAGE);
-
+		set_zoom_items_sensitivity(control, FALSE);
+	}
 	gtk_widget_unref(GTK_WIDGET(gs));
 }
 
@@ -365,6 +445,14 @@ ggv_control_button_press_event(GtkWidget *widget, GdkEventButton *event,
 	return FALSE;
 }
 
+static gboolean
+ggv_control_popup_menu(GtkWidget *widget, gpointer data)
+{
+	GgvControl *control = GGV_CONTROL(data);
+
+	return bonobo_control_do_popup(BONOBO_CONTROL(control), 3, GDK_CURRENT_TIME);
+}
+
 static gboolean
 ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 							gpointer data)
@@ -383,21 +471,33 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_DOWN, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		case GTK_GS_ORIENTATION_LANDSCAPE:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_LEFT, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		case GTK_GS_ORIENTATION_SEASCAPE:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_RIGHT, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		case GTK_GS_ORIENTATION_UPSIDEDOWN:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_UP, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		default:
 			break;
@@ -410,21 +510,33 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_UP, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		case GTK_GS_ORIENTATION_LANDSCAPE:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_RIGHT, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		case GTK_GS_ORIENTATION_SEASCAPE:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_LEFT, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		case GTK_GS_ORIENTATION_UPSIDEDOWN:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_DOWN, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 			}
+			else
+				gtk_widget_queue_draw
+					(GTK_SCROLLED_WINDOW(control->priv->root)->vscrollbar);
 			break;
 		default:
 			break;
@@ -548,43 +660,6 @@ verb_ZoomToFitWidth_cb (BonoboUIComponent *uic, gpointer user_data,
 
 }
 
-static void
-_set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolean sens)
-{
-	gchar *prop_val = sens?"1":"0";
-	Bonobo_UIContainer container;
-	gint i;
-
-	container = bonobo_ui_component_get_container (uic);
-	if (container == CORBA_OBJECT_NIL)
-		return;
-
-	bonobo_ui_component_freeze(uic, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/ZoomIn",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/ZoomOut",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/ZoomToDefault",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/ZoomToFit",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/ZoomToFitWidth",
-								 "sensitive", prop_val, NULL);
-	for(i = 0; zoom_level_items[i].path != NULL; i++) {
-		bonobo_ui_component_set_prop(uic, zoom_level_items[i].path,
-									 "sensitive", prop_val, NULL);
-	}
-	bonobo_ui_component_thaw(uic, NULL);
-}
-
-static void
-set_zoom_items_sensitivity(GgvControl *control, gboolean sens)
-{
-	_set_zoom_items_sensitivity(control, control->priv->uic, sens);
-	if(control->priv->popup_uic != NULL)
-		_set_zoom_items_sensitivity(control, control->priv->popup_uic, sens);
-}
-
 static void
 set_auto_fit_items_sensitivity(GgvControl *control, gboolean sens)
 {
@@ -609,6 +684,7 @@ static void
 set_command_items_sensitivity(GgvControl *control, gboolean sens)
 {
 	set_auto_fit_items_sensitivity(control, sens);
+	sens = sens & !is_auto_fit_set(control);
 	set_zoom_items_sensitivity(control, sens);
 }
 
@@ -862,6 +938,8 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 					 G_CALLBACK(ggv_control_key_press_event), control);
 	g_signal_connect(G_OBJECT(view), "button_press_event",
 					 G_CALLBACK(ggv_control_button_press_event), control);
+	g_signal_connect(G_OBJECT(view), "popup_menu",
+					 G_CALLBACK(ggv_control_popup_menu), control);
 
 	control->priv->root = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(control->priv->root);
@@ -885,6 +963,10 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 					 "button_release_event",
 					 G_CALLBACK(scrollbar_button_release_event),
 					 view);
+	g_signal_connect(G_OBJECT(GTK_SCROLLED_WINDOW(control->priv->root)),
+					 "size_allocate",
+					 G_CALLBACK(sw_size_allocate),
+					 view);
 	gtk_container_add(GTK_CONTAINER(control->priv->root), view);
 	
 	bonobo_control_construct (BONOBO_CONTROL (control), control->priv->root);
