@@ -2,7 +2,7 @@
 /*
  * ggv-prefs-ui.h: GGV preferences ui
  *
- * Copyright (C) 2002 the Free Software Foundation
+ * Copyright (C) 2002, 2003 the Free Software Foundation
  *
  * Author: Jaka Mocnik  <jaka@gnu.org>
  */
@@ -31,7 +31,7 @@ typedef struct _GgvPrefsDialogClass GgvPrefsDialogClass;
 
 struct _GgvPrefsDialog
 {
-        GtkWindow dlg;
+        GtkDialog dlg;
 
         GtkWidget *notebook;
 
@@ -48,13 +48,11 @@ struct _GgvPrefsDialog
         GtkWidget **unit_choice;               /* unit items */
         GtkWidget **auto_fit_choice;           /* auto-fit mode */
         GtkWidget *scroll_step;
-
-        GtkWidget *ok, *cancel, *apply;
 };
 
 struct _GgvPrefsDialogClass
 {
-        GtkWindowClass klass;
+        GtkDialogClass klass;
 };
 
 GType ggv_prefs_dialog_get_type(void);
