@@ -13,15 +13,13 @@
 #include "ggvutils.h"
 #include "gsdefaults.h"
 
-static GConfClient *gconf_client = NULL;
-
 gchar    *ggv_print_cmd = NULL;
 gboolean  ggv_save_geometry = FALSE;
 gint      ggv_default_width = DEFAULT_WINDOW_WIDTH;
 gint      ggv_default_height = DEFAULT_WINDOW_HEIGHT;
 
 gboolean ggv_panel = TRUE, ggv_menubar = TRUE, ggv_toolbar = TRUE;
-gboolean ggv_statusbar = TRUE, ggv_autojump = TRUE;
+gboolean ggv_statusbar = TRUE, ggv_autojump = TRUE, ggv_pageflip = FALSE;
 GgvToolbarStyle ggv_toolbar_style = GGV_TOOLBAR_STYLE_DEFAULT;
 gboolean ggv_right_panel = FALSE;
 
@@ -30,9 +28,11 @@ gint ggv_unit_index = 0;
 void
 ggv_prefs_load()
 {
+        GConfClient *gconf_client;
+
         gtk_gs_defaults_load();
 
-        ggv_prefs_gconf_client();
+        gconf_client = ggv_prefs_gconf_client();
 
         if(ggv_print_cmd)
                 g_free(ggv_print_cmd);
@@ -63,6 +63,9 @@ ggv_prefs_load()
         ggv_autojump = gconf_client_get_bool(gconf_client,
                                               "/apps/ggv/control/autojump",
                                               NULL);
+        ggv_pageflip = gconf_client_get_bool(gconf_client,
+                                             "/apps/ggv/control/pageflip",
+                                             NULL);
         ggv_right_panel = gconf_client_get_bool(gconf_client,
                                                "/apps/ggv/layout/rightpanel",
                                                NULL);
@@ -77,39 +80,6 @@ ggv_prefs_load()
                 ggv_default_height = DEFAULT_WINDOW_HEIGHT;
 }
 
-void
-ggv_prefs_save()
-{
-        ggv_prefs_gconf_client();
-
-        gconf_client_set_string(gconf_client, "/apps/ggv/printing/command",
-                                ggv_print_cmd, NULL);
-        gconf_client_set_int(gconf_client, "/apps/ggv/coordinates/units",
-                             ggv_unit_index, NULL);
-        gconf_client_set_bool(gconf_client, "/apps/ggv/layout/showpanel", 
-                              ggv_panel, NULL);
-	gconf_client_set_bool(gconf_client, "/apps/ggv/layout/showtoolbar",
-                              ggv_toolbar, NULL);
-        gconf_client_set_int(gconf_client, "/apps/ggv/layout/toolbarstyle",
-                             ggv_toolbar_style, NULL);
-        gconf_client_set_bool(gconf_client, "/apps/ggv/layout/showmenubar",
-                              ggv_menubar, NULL);
-	gconf_client_set_bool(gconf_client, "/apps/ggv/layout/showstatusbar",
-                              ggv_statusbar, NULL);
-        gconf_client_set_bool(gconf_client, "/apps/ggv/layout/savegeometry",
-                              ggv_save_geometry, NULL);
-        gconf_client_set_bool(gconf_client, "/apps/ggv/control/autojump",
-                              ggv_autojump, NULL);
-        gconf_client_set_bool(gconf_client, "/apps/ggv/layout/rightpanel",
-                              ggv_right_panel, NULL);
-        if(ggv_save_geometry) {
-                gconf_client_set_int(gconf_client, "/apps/ggv/layout/windowwidth",
-                                     ggv_default_width, NULL);
-                gconf_client_set_int(gconf_client, "/apps/ggv/layout/windowheight",
-                                     ggv_default_height, NULL);
-        }
-}
-
 static void
 ggv_prefs_changed(GConfClient* client, guint cnxn_id,
                   GConfEntry *entry, gpointer user_data)
@@ -122,56 +92,61 @@ ggv_prefs_changed(GConfClient* client, guint cnxn_id,
                         ggv_print_cmd = g_strdup(LPR_PATH " %s");
         }
         else if(!strcmp(entry->key, "/apps/ggv/coordinates/units")) {
-                ggv_unit_index = gconf_client_get_int(gconf_client, "/apps/ggv/coordinates/units",
+                ggv_unit_index = gconf_client_get_int(client, "/apps/ggv/coordinates/units",
                                                       NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showpanel")) {
-                ggv_panel = gconf_client_get_bool(gconf_client,
+                ggv_panel = gconf_client_get_bool(client,
                                                   "/apps/ggv/layout/showpanel",
                                                   NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showtoolbar")) {
-                ggv_toolbar = gconf_client_get_bool(gconf_client,
+                ggv_toolbar = gconf_client_get_bool(client,
                                                     "/apps/ggv/layout/showtoolbar",
                                                     NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showstatusbar")) {
-                ggv_statusbar = gconf_client_get_bool(gconf_client,
+                ggv_statusbar = gconf_client_get_bool(client,
                                                     "/apps/ggv/layout/showstatusbar",
                                                     NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/toolbarstyle")) {
-                ggv_toolbar_style = gconf_client_get_int(gconf_client,
+                ggv_toolbar_style = gconf_client_get_int(client,
                                                          "/apps/ggv/layout/toolbarstyle",
                                                          NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showmenubar")) {
-                ggv_menubar = gconf_client_get_bool(gconf_client,
+                ggv_menubar = gconf_client_get_bool(client,
                                                     "/apps/ggv/layout/showmenubar",
                                                     NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/control/autojump")) {
-                ggv_autojump = gconf_client_get_bool(gconf_client,
+                ggv_autojump = gconf_client_get_bool(client,
                                                      "/apps/ggv/control/autojump",
                                                      NULL);
         }
+        else if(!strcmp(entry->key, "/apps/ggv/control/pageflip")) {
+                ggv_pageflip = gconf_client_get_bool(client,
+                                                     "/apps/ggv/control/pageflip",
+                                                     NULL);
+        }
         else if(!strcmp(entry->key, "/apps/ggv/layout/rightpanel")) {
-                ggv_right_panel = gconf_client_get_bool(gconf_client,
+                ggv_right_panel = gconf_client_get_bool(client,
                                                        "/apps/ggv/layout/rightpanel",
                                                        NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/savegeometry")) {
                 ggv_save_geometry = gconf_client_get_bool
-                        (gconf_client, "/apps/ggv/layout/savegeometry", NULL);
+                        (client, "/apps/ggv/layout/savegeometry", NULL);
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/windowwidth")) {
                 if((ggv_default_width = gconf_client_get_int
-                    (gconf_client, "/apps/ggv/layout/windowwidth", NULL)) == 0)
+                    (client, "/apps/ggv/layout/windowwidth", NULL)) == 0)
                         ggv_default_width = DEFAULT_WINDOW_WIDTH;
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/windowheight")) {
                 if((ggv_default_height = gconf_client_get_int
-                    (gconf_client, "/apps/ggv/layout/windowheight", NULL)) == 0)
+                    (client, "/apps/ggv/layout/windowheight", NULL)) == 0)
                         ggv_default_height = DEFAULT_WINDOW_HEIGHT;
         }
 }
@@ -179,6 +154,8 @@ ggv_prefs_changed(GConfClient* client, guint cnxn_id,
 GConfClient *
 ggv_prefs_gconf_client()
 {
+        static GConfClient *gconf_client = NULL;
+
         if(!gconf_client) {
                 g_assert(gconf_is_initialized());
                 gconf_client = gconf_client_get_default();
@@ -192,3 +169,4 @@ ggv_prefs_gconf_client()
 
         return gconf_client;
 }
+
