@@ -152,7 +152,6 @@ static gboolean broken_pipe = FALSE;
 
 static void catchPipe(int i)
 {
-        g_message("in catch Pipe!!!\n");
         broken_pipe = True;
 }
 
@@ -546,7 +545,8 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 	 * This is a bit messy:
 	 * we want to make sure that we do the right thing if dragged.
 	 */
-	if (gs->widget.allocation.width >= gs->width) {
+	if (gs->widget.allocation.width >= gs->width ||
+            gs->zoom_mode != GTK_GS_ZOOM_ABSOLUTE) {
 		x = (gs->widget.allocation.width - gs->width)/2;
 		gs->hadj->value = 0.0;
 		gs->hadj->page_size = 1.0;
@@ -562,7 +562,8 @@ gtk_gs_munge_adjustments (GtkGS *gs)
                 gs->hadj->step_increment = 1.0/gs->width;
 		gs->hadj->value = -((gfloat)x)/gs->width;
 	}
-	if (gs->widget.allocation.height >= gs->height) {
+	if (gs->widget.allocation.height >= gs->height ||
+            gs->zoom_mode == GTK_GS_ZOOM_FIT_PAGE) {
 		y = (gs->widget.allocation.height - gs->height)/2;
 		gs->vadj->value = 0.0;
 		gs->vadj->page_size = 1.0;
@@ -681,14 +682,14 @@ gtk_gs_size_allocate (GtkWidget     *widget,
         /* 
          * update the adjustment if necessary (ie. a resize);
          */
-        if (gs->zoom_mode == GTK_GS_ZOOM_ABSOLUTE) {
-                if (GTK_WIDGET_REALIZED(gs)) {
-                        gtk_gs_munge_adjustments (gs);
-                }
-        }
-        else {
+#if 0
+        if (gs->zoom_mode != GTK_GS_ZOOM_ABSOLUTE) {
                 gtk_gs_set_zoom(gs, 0.0);
         }
+#endif
+        if (GTK_WIDGET_REALIZED(gs)) {
+                gtk_gs_munge_adjustments (gs);
+        }
 
         gtk_gs_goto_page(gs, gs->current_page);
 }
@@ -846,7 +847,7 @@ set_up_page (GtkGS *gs)
         GdkGC *fill;
         GdkColor white = {0, 0xFFFF, 0xFFFF, 0xFFFF}; /* pixel, r, g, b */
 
-#ifdef HAVE_SETLOCALE
+#ifdef HAVE_LOCALE_H
         char *savelocale;
 #endif
 
@@ -894,7 +895,7 @@ set_up_page (GtkGS *gs)
                 }
         }
 
-#ifdef HAVE_SETLOCALE
+#ifdef HAVE_LOCALE_H
         /* gs needs floating point parameters with '.' as decimal point
          * while some (european) locales use ',' instead, so we set the 
          * locale for this snprintf to "C".
@@ -917,7 +918,7 @@ set_up_page (GtkGS *gs)
                    gs->right_margin,
                    gs->top_margin);
 
-#ifdef HAVE_SETLOCALE
+#ifdef HAVE_LOCALE_H
         setlocale (LC_NUMERIC, savelocale);
 #endif
         gdk_property_change(gs->pstarget,
@@ -1242,7 +1243,7 @@ stop_interpreter (GtkGS *gs)
         if (gs->interpreter_pid > 0) {
                 int status = 0;
                 kill(gs->interpreter_pid, SIGTERM);
-                wait(&status);
+                while ((wait (&status) == -1) && (errno == EINTR)); 
 		gs->interpreter_pid = -1;
                 if(status == 1) {
                         gtk_gs_cleanup(gs);
@@ -2195,8 +2196,9 @@ gtk_gs_set_zoom (GtkGS *gs, gfloat zoom) {
                 zoom = ggv_zoom_levels[ggv_max_zoom_levels];
         if (fabs(gs->zoom_factor - zoom) > 0.001) { 
                 gs->zoom_factor = zoom;
-                if (GTK_WIDGET_REALIZED(gs)) 
+                if (GTK_WIDGET_REALIZED(gs)) {
                         set_up_page(gs);
+                }
                 gs->changed = TRUE;
                 gtk_widget_queue_resize (&(gs->widget));
         }
@@ -2216,15 +2218,18 @@ gtk_gs_zoom_to_fit(GtkGS *gs, gboolean fit_width)
 {
         gint new_y;
         gfloat new_zoom;
+        guint avail_w, avail_h;
 
         g_return_val_if_fail(gs != NULL, 0.0);
         g_return_val_if_fail(GTK_IS_GS(gs), 0.0);
-        
-	new_zoom = (gfloat)gs->widget.allocation.width/(gfloat)gs->width*gs->zoom_factor;
+
+        avail_w = (gs->avail_w > 0)?gs->avail_w:gs->width;
+        avail_h = (gs->avail_h > 0)?gs->avail_h:gs->height;
+	new_zoom = (gfloat)avail_w/(gfloat)gs->width*gs->zoom_factor;
 	if(!fit_width) {
-		new_y = new_zoom*gs->height/gs->zoom_factor;
-		if(new_y > gs->widget.allocation.height)
-			new_zoom = (gfloat)gs->widget.allocation.height/(gfloat)gs->height*gs->zoom_factor;
+		new_y = new_zoom*(gfloat)gs->width/gs->zoom_factor;
+		if(new_y > avail_h)
+			new_zoom = (gfloat)avail_h/(gfloat)gs->height*gs->zoom_factor;
 	}
 
         return new_zoom;
@@ -2779,3 +2784,13 @@ gtk_gs_get_zoom_mode(GtkGS *gs)
 {
         return gs->zoom_mode;
 }
+
+void
+gtk_gs_set_available_size(GtkGS *gs, guint avail_w, guint avail_h)
+{
+        gs->avail_w = avail_w;
+        gs->avail_h = avail_h;
+        if (gs->zoom_mode != GTK_GS_ZOOM_ABSOLUTE) {
+                gtk_gs_set_zoom(gs, 0.0);
+        }
+}
